Corrected declaration of __ockl_clz_u64() (#1340)

[ROCm/hip commit: 0e3198be25]
这个提交包含在:
kpyzhov
2019-08-20 08:06:36 -04:00
提交者 Maneesh Gupta
父节点 3f704a3303
当前提交 612833bcfe
修改 2 个文件,包含 3 行新增2 行删除
@@ -50,7 +50,7 @@ __device__ static inline int __clz(int input) {
}
__device__ static inline int __clzll(long long int input) {
return __ockl_clz_u64((ulong)input);
return __ockl_clz_u64((ullong)input);
}
__device__ static inline unsigned int __ffs(unsigned int input) {
@@ -34,6 +34,7 @@ typedef unsigned char uchar;
typedef unsigned short ushort;
typedef unsigned int uint;
typedef unsigned long ulong;
typedef unsigned long long ullong;
extern "C" __device__ __attribute__((const)) bool __ockl_wfany_i32(int);
extern "C" __device__ __attribute__((const)) bool __ockl_wfall_i32(int);
@@ -48,7 +49,7 @@ extern "C" __device__ __attribute__((const)) uint __ockl_sad_u32(uint, uint, uin
extern "C" __device__ __attribute__((const)) uchar __ockl_clz_u8(uchar);
extern "C" __device__ __attribute__((const)) ushort __ockl_clz_u16(ushort);
extern "C" __device__ __attribute__((const)) uint __ockl_clz_u32(uint);
extern "C" __device__ __attribute__((const)) ulong __ockl_clz_u64(ulong);
extern "C" __device__ __attribute__((const)) ullong __ockl_clz_u64(ullong);
extern "C" __device__ __attribute__((const)) float __ocml_floor_f32(float);
extern "C" __device__ __attribute__((const)) float __ocml_rint_f32(float);